Mostrando entradas con la etiqueta linux. Mostrar todas las entradas
Mostrando entradas con la etiqueta linux. Mostrar todas las entradas

lunes, 9 de julio de 2018

Slackware post-instalación

Luego de la instalación quizá no nos guste Slackware desde consola. Vamos a realizar algunos cambios que mejorarán el uso de Slackware después de la instalación.

1. Arranque rápido

Al terminar la instalación e iniciar Slackware por primera vez el Lilo toma 2 minutos de espera. Vamos a disminuir este tiempo a 3 segundos. Para esto debemos editar el archivo /etc/lilo.conf
#nano /etc/lilo.conf
Buscamos la sección
timeout = 1200
y la cambiamos por
timeout = 30

Guardamos el archivo (Ctrl+O) y salimos (Ctrl+X)

luego ejecutamos el programa
#lilo
Con esto se carga la nueva configuración, y en el siguiente reinicio tendremos la carga rápida.

2. Crear un usuario 

Es critico para la seguridad usar el usuario root por los permisos que tiene, así que es recomendable tener un usuario no administrador, que se encargue de usar el sistema como un usuario de escritorio. Para esto vamos a crear un usuario llamado "warhammer" (pueden darle otro nombre)
#adduser warhammer
Llenamos los datos que nos piden
Con esto ya debemos de tener creado el usuario

Vamos a darle permisos en sudoers para poder realizar actividades de administrador usando el comando sudo.
#nano /etc/sudoers
en la sección "User privilege specification" añadiremos a nuestro usuario
warhammer ALL=(ALL) ALL
Guardamos y salimos (Ctrl+O Ctrl+X)

3. Iniciar con interface gráfica XFCE 

Para hacer amigable el inicio con una interface gráfica modificaremos el archivo /etc/inittab
#nano /etc/inittab
Buscamos la sección
id:3:initdefault:
Cambiaremos el valor 3 por 4
id:4:initdefault:

Guardamos y salimos (Ctrl+O Ctrl+X)

4. Reiniciamos para cargar la nueva configuración
#shutdown -r 0

Ahora a disfrutar de Slackware con una interface gráfica y un usuario de escritorio. 

instalar Slackware 14.2

Hoy vamos a realizar una instalación básica de Slackware.

Como entorno para la instalación tenemos un PC con las siguientes caracteristicas
- Procesador Core 2 Duo
- 1GB de Ram
- 1HD de 64GB
- Teclado español latinoamericano

0. Preparativos previos:

Descargamos la ISO de slackware de
https://mirrors.slackware.com/slackware/slackware-iso/slackware64-14.2-iso/slackware64-14.2-install-dvd.iso
esta ISO pesa 2.6GB la quemamos en un DVD

1. Inicio

Para iniciar debemos de configurar nuestro BIOS para que cargue desde la unidad DVD e iniciar el booteo con el DVD.

Tendremos una pantalla sencilla y muy agradable:
En esta parte podemos indicar como iniciaremos el instalador, quizá necesitemos algunas características especiales para soportar dispositivos, o solo haremos un testeo de memoria. En otro post explicaremos como usar esto a mayor detalle. 

Por ahora daremos [ENTER]

2. Teclado

Tendremos una pantalla para la selección del teclado, para seleccionar el teclado es necesario poner el valor 1 [ENTER] en : 

Luego debemos seleccionar la opción correspondiente a nuestro teclado de la lista:

Al seleccionar la correcta configuración del teclado, puedes probar el mismo en el cuadro de texto que aparece a continuación. Si todo esta bien presionas [ENTER] 1 [ENTER], si todavía no es el teclado que te corresponde regresas a la pantalla de selección escribiendo [ENTER] 2 [ENTER]. 

En mi caso seleccione qwerty/la-latin1.map

3. Particionar el disco

En esta parte, primero nos pedirá loguearnos con usuario root (sin clave) y tendremos a linea de consola a nuestra disposición. 

Para particionar usaremos la herramienta cfdisk, pero si tienes mas experiencia utiliza fdisk (no hay problema
# cfdisk

- La primera parte indica el tipo de LABEL que pondremos al disco, pongamos por defecto DOS[ENTER], tendremos una pantalla como la siguiente:

Bueno ahora crearemos una estructura para nuestros disco duro, calculamos los tamaños de las unidades a crear de acuerdo a nuestra necesidad.
- Por defecto separa el tamaño de 2 x RAM para una memoria de intercambio SWAP
- Por defecto separamos 10GB para los archivos base de sistema. Slackware corre en 7GB con todos los paquetes instalados. 
- Si utilizaremos el disco para oficina, el resto de espacio debemos usarlo para la unidad que apunte a  /home (archivos de los usuarios), también aplica si usaras la máquina par servidor FTP
- Si usaremos el disco para un servidor de base de datos, webserver , la carpeta /var debe ser la de mayor tamaño.
Nosotros la usaremos para escritorio por tanto el particionado será de la siguiente manera:
- root: 10GB
- SWAP: 2GB  
- home: 52GB o restante, hay un espacio que ocupa la tabla de particiones y lo restante puede ser menor. 

Partición root:
new [ENTER] -> partition size: 10G [ENTER]-> primary [ENTER] 
type: 83 LINUX [ENTER] 
Bootable [ENTER]


Partición swap
FreeSpace
new [ENTER] -> partition size: 2G [ENTER] -> primary [ENTER]
type: 82 LINUX SWAP[ENTER]

Partición home
FreeSpace
new [ENTER] -> partition size: 52G [ENTER] -> primary [ENTER]
type: 83 LINUX [ENTER]

Tendremos al finalizar la siguiente estructura:


Luego escribiremos el disco con los cambios, con la opción write [ENTER] yes [ENTER], Si todo va bien tendremos el mensaje:
the partition table has been altered.

Luego de esto saldremos de cfdisk con quit[ENTER]

4. Formateo y distribución de unidades


Regresando a  línea de comandos con el usuario root y teniendo los requisitos listos debemos de iniciar la instalación con :
# setup[ENTER]

Vamos a iniciar con la opción 3 ADD SWAP [ENTER]

El instalador debe mostrar por defecto la unidad marcada como SWAP. Nos permite verificar si debemos ejecutar mkswap en la unidad, en este caso pondremos YES[ENTER]

Listo tenemos nuestra SWAP. Presionamos OK[ENTER]
Ahora debemos de seleccionar nuestra unidad root (raiz o /), como recordamos en el inicio indicamos que sería el de 10G (adicionalmente cuando lo particionamos lo marcamos como booteable). Presionamos SELECT[ENTER]
Recomiendo formatear con la segunda opcion (CHECK), sobre todo con los discos que ya tienen un tiempo de vida medio, así verificamos los bloques dañados. Si es un disco nuevo podremos dar la primera opción. 

Presionamos OK [ENTER]
Nos toca seleccionar el sistema de archivos, por defecto tenemos seleccionado la ultima versión estable de ext4. Presionamos [OK]

El instalador de slackware detectara la otra partición y nos preguntara para que la usaremos:
Presionamos SELECT[ENTER], luego nos indicara para formatear la unidad. Por defecto la formateamos y nos indicará a que carpeta lo vamos a apuntar
En esta sección pondremos /home  OK[ENTER]
Luego nos dará un resumen de los cambios que se van a realizar, solo los aceptamos [OK]

5. Instalación

En esta parte vamos a instalar los paquetes en nuestro sistema. Primero debemos seleccionar la unidad desde donde instalaremos:
Como lo  estamos instalando desde DVD, seleccionamos la primera opción y presionamos OK[ENTER]
Nos indicará si deseamos hacer una revisión del disco, lo ponemos por defecto la primera opción y presionamos OK[ENTER]

En esta parte tendremos que escoger los paquetes a instalar, podemos dejarlo por defecto, pero como tengo una PC con pocos recursos, voy excluir o desmarcar lo siguiente:
- KDE
- Games

Listo, presionamos OK[ENTER]
Podemos tener mayor control de lo que vamos a instalar en esta ventana. Por ahora seleccionaremos la primera opcion FULL -> OK [ENTER]

Y arrancan... comienza la instalación. Podemos dejar esto corriendo hasta que termine. 

6. Configurar el Arranque

Luego de terminada la instalación de paquetes nos preguntara si deseamos crear un usb booteable, por el momento nos saltamos este paso Skip OK[ENTER]


Luego tendremos que seleccionar la configuración del lanzador de Linux (lilo) dejamos la configuración por defecto 

simple OK[ENTER]

De igual forma en la selección de la interface que nos mostrara al iniciar el linux, seleccionamos standard OK[ENTER]

En el siguiente paso nos preguntará si queremos añadir parámetros adicionales al kernel, lo dejamos vacío y continuamos. 

Luego tendremos que activar el UTF-8 para las consolas, en la pantalla siguiente ponemos Yes[ENTER]

También tendremos que indicar donde instalar el arrancador, lo dejamos por defecto con MBR OK[ENTER]


Ahora debemos de seleccionar como esta conectado el mouse, en mi caso USB


OK[ENTER] y para configurar la linea que carga el mouse YES[ENTER]

7. Red y servicios

En esta parte vamos a configurar la red y los servicios:


Nos pedirá llenar algunos valores como:
hostname: mipc.com
domain: mipc.com

Luego podremos activar algunos servicios o demonios que queremos cargar al iniciar la PC. La dejamos por defecto. 

Luego nos preguntara sobre "Console font configuration" lo dejamos por defecto NO OK[ENTER]

Al seleccionar el tipo de configuración del reloj, lo dejamos por defecto. 

Luego debemos de escoger la zona horaria, en mi caso America/Lima OK[ENTER]


8. Escritorio de trabajo 

Vamos a configurar el escritorio de trabajo en el siguiente paso. Por ahora usaremos xinitrc.xfce OK[ENTER]

Finalmente asignaremos el password al usuario root 
el usuario root sera nuestro administrador, asi que no olvidemos el password. YES[ENTER]
Ingresamos y reingresamos el password y tendríamos terminada la instalación. OK[ENTER]


Listo , hemos regresado al menú de pasos y aquí debemos escoger EXIT OK[ENTER] y extraer el DVD de instalación. 
A la pregunta de reboot, reiniciamos el sistema. 


No debemos esperar el tiempo que dice abajo, presionamos enter y ya debe iniciar el arranque de Slackware. 



lunes, 25 de junio de 2018

Linux: Comparar 2 archivos binarios

En esta ocasión vamos a verificar que un archivo es igual a otro, pero vamos a compara archivos binarios.

En mi caso he copiado un archivo ISO de un disco duro extorno a la PC y quiero verificar si se ha copiado correctamente. Para esto usamos diff <archivo1> <archivo2>

# diff /media/usb/archivo.iso ./archivo.iso

Si diff no envía mensaje de diferencia el archivo es idéntico, en caso contrario son distintos.


Linux: Crear un USB booteable

En esta ocasión vamos a crear un USB booteable partiendo de una ISO, esto sobre nuestro querido GNU/Linux.

1. Primero vamos a detectar el USB, para esto insertamos el USB en la PC y en consola ejecutamos
# sudo fdisk -l 
Nos aparecerá la unidad añadida, en mi caso es una unidad de 8G y formato FAT32


Como observamos nuestro dispositivo es /dev/sdb1, ahora desmontamos el dispositivo para poder iniciar el copiado.
# umount /dev/sdb1

2. Comenzamos a realizar la copia de la imagen ISO usando el comando dd, uno de los parámetros principales serán if (archivo de entrada o ISO) y of (archivo de salida o unidad USB)
# sudo dd bs=4M if=TuArchivo.iso of=/dev/sdb
Si observan el valor de of no esta completo /dev/sdb , le falta el valor 1 (/dev/sdb1) esto indica que estamos apuntando a toda la unidad y no a una partición de esta.

Ahora debemos esperar un poco hasta que se termine el copiado del archivo.

PD. Para crear un USB booteable con Windows 10 es necesario usar WoeUSB.

lunes, 27 de octubre de 2014

Error instalando RSA en GNU/Linux (libstdc++.so.5)

Al instalar IBM RSA recientemente en GNU/Linux Ubuntu aparece el problema: "libstdc++.so.6 and libstdc++.so.5 not found in LIBRARY PATH" para solucionar el problema seguiremos los siguientes pasos:

Primero instalamos la librería libstdc++.so.5 en ubuntu
$sudo apt-get install libstdc++5 libstdc++5:i386

Luego debemos de crear un enlace simbólico a una carpeta accesible al RSA:

$sudo ln -s /usr/lib/i386-linux-gnu/libstdc++.so.5 /usr/lib32/libstdc++.so.5

Listo, ahora si podemos instalar RSA
$sudo RSA_SETUP/InstallerImage_linux_gtk_x86/install

lunes, 26 de agosto de 2013

Linux + Android SDK + Célular Android (USB Drivers)

El presente es un tutorial para conectar Android SDK con los célulares Android de distintos fabricantes.

Lo primero que tenemos que hacer es detectar es el fabricante de nuestro célular. Para eso conectamos por USB el célular a la PC y ejecutamos

#lsusb

Tendremos una lista con los distintos puertos USB y el fabricante del dispositivo conectado.

El fabricante de mi dispositivo (célular) es el siguiente:

Bus 005 Device 006: ID 0fce:6193 Sony Ericsson Mobile Communications AB

Si todavía no encuentran el suyo pueden probar ejecutando "lsusb" con y sin conectar por USB el célular. El que se añadede en la lista será el de su célular.

Uno de los parametros de la línea extraida es el Id del fabricante, a continuación lo marcamos de rojo:

Bus 005 Device 006: ID 0fce:6193 Sony Ericsson Mobile Communications AB 

Luego de que tenemos detectado el Id del fabricante tendremos que editar o crear el archivo (como usuario root):
#/etc/udev/rules.d/51-android.rules

En este archivo añadimos la siguiente línea
SUBSYSTEM=="usb", ATTR{idVendor}=="0fce", MODE="0666", GROUP="plugdev" 

Noten que el Id del fabricante esta marcado de rojo. Este es el valor de nuestro fabricante de dispositivo (Célular)

Nos queda darle permisos al archivo:
#chmod a+r /etc/udev/rules.d/51-android.rules

Desconectamos y conectamos el USB de conexión al célular y probamos con la herramienta del SDK Android (sdk/platform-tools)
#adb devices
List of devices attached
BX903H993B    device


Listo hemos logrado la conexión de nuestro Android SDK con nuestro dispositivo android y podemos comenzar a desarrollar.

martes, 16 de agosto de 2011

Debian cumple 18 años

Debian cumple 18 años: "Como cada 16 de agosto desde hace 18 años hoy se celebra el Debian Day, el cumpleaños del “sistema operativo universal” que en esta ocasión llega nada menos que a su “mayoría de edad”. Fue el 16 de agosto de 1993 cuando Ian Murdock comenzó un proyecto que seguramente ha sobrepasado sus mejores expectativas, convirtiéndose [...]


Related posts:
  1. Debian cumple 17 añitos

  2. Debian cumple 15 años

  3. Debian 6.0 tendrá un kernel completamente libre de código propietario
"

lunes, 22 de noviembre de 2010

Mejorar el rendimiento de GNU/Linux

Lennart Poettering, un desarrollador de Red Hat, ha descubierto una forma de mejorar el rendimiento del sistema operativo GNU/Linux. A continuación mostramos la forma de hacerlo.

Para Ubuntu

Abrir el archivo /etc/rc.local y encima de la línea exit 0 añadir las siguientes líneas:
mkdir -p /dev/cgroup/cpu
mount -t cgroup cgroup /dev/cgroup/cpu -o cpu
mkdir -m 0777 /dev/cgroup/cpu/user
echo "1" > /dev/cgroup/cpu/user/notify_on_release
echo "/usr/local/sbin/cgroup_clean" > /dev/cgroup/cpu/release_agent

Convertimos el fichero en ejecutable:
$sudo chmod +x /etc/rc.local

A nuestro archivo ~/.bashrc añadimos las líneas:
if [ "$PS1" ] ; then
mkdir -m 0700 /dev/cgroup/cpu/user/$$
echo $$ > /dev/cgroup/cpu/user/$/tasks
fi

Creamos el archivo /usr/local/sbin/cgroup_clean con las siguientes líneas:
#!/bin/sh
rmdir /dev/cgroup/cpu/$1

Convertimos en ejecutable el archivo creado:
$sudo chmod +x /usr/local/sbin/cgroup_clean

Como paso final reiniciamos la maquina o ejecutamos el archivo /etc/rc.local
$sudo /etc/rc.local

Para otras distribuciones

Añadir al archivo ~/.bashrc las siguientes líneas:
if [ "$PS1" ] ; then
mkdir -m 0700 /sys/fs/cgroup/cpu/user/$
echo $ > /sys/fs/cgroup/cpu/user/$/tasks
fi

Ejecutamos como super usuario las siguientes líneas:
#mount -t cgroup cgroup /sys/fs/cgroup/cpu -o cpu
#mkdir -m 0777 /sys/fs/cgroup/cpu/user

Fuente: http://pastebin.com/raw.php?i=sHRYRuAN

lunes, 19 de julio de 2010

OpenSuse 11.3 y php5-firebird

Descargamos la versión indicada para nuestra distribución de la siguiente página :
http://fr2.rpmfind.net/linux/rpm2html/search.php?query=php-firebird

Instalamos el archivo indicado para nuestra plataforma (x86_64 en mi caso):
Firebird database module for PHP Mandriva 2010.1 for x86_64 -
ftp://fr2.rpmfind.net/linux/Mandriva/official/2010.1/x86_64/media/contrib/release/php-firebird-5.3.2-1mdv2010.1.x86_64.rpm

Ubicamos los archivos instalados con la estructura de OpenSuse
# ln -s /etc/php.d/42_firebird.ini /etc/php5/conf.d/firebird.ini
# ln -s /usr/lib64/php/extensions/interbase.so /usr/lib64/php5/extensions/interbase.so

Reiniciamos el servidor
# service apache2 restart

martes, 15 de septiembre de 2009

Kdm error al cerrar sesión

Despues de instalar mi querido Slackware 13, con KDE 4; he tenido un pequeño problema al cerrar sesión. La pantalla se pone negra y se congela en ese estado, para salir de esto solo es necesario poner Ctrl+Alt+F1, y de ahi reiniciar Ctrl+Alt+Del.

Ahora vamos a solucionar el problema.

Paso 1:
Editar el archivo /etc/kde/kdm/kdmrc
#emacs /etc/kde/kdm/kdmrc
buscamos el bloque de configuración : [X-*-Core]
y añadimos (si es que no existe) la siguiente línea:
TerminateServer=true
y guardamos

Paso 2:
Reiniciamos la PC y listo, la siguiente vez no tendremos el problemas al cerrar sesión de nuestro KDE.

Suerte

miércoles, 1 de julio de 2009

Slackware y Firefox 3.5

Excelente, ya salio el nuevo firefox 3.5 y lo menos que podemos hacer es instalarlo en nuestor querido Slackware.

Paso 1:
Comenzamos descargando nuestra versión desde la página de firefox desde la página http://www.mozilla-europe.org/es/firefox/ o haciendo click en nuestro enlace:
http://download.mozilla.org/?product=firefox-3.5&os=linux&lang=es-ES

Paso 2:
Descomprimimos el archivo descargado:
#tar -jxvf firefox-3.5.tar.bz2
veremos que se creo la carpeta firefox la cual deberemos mover a la carpeta opt

Paso 3:
#mv firefox /opt

Listo ya lo tenemos instalado, ahora solo debemos ejecutarlo:
/opt/firefox/firefox

Wow, impresionantemente veloz, después del primer arranque.

¿Problemas al instalar plugins?

Al parecer hay problemas al instalar los plugins en firefox, bueno al menos en Slackware, pero se soluciona facilmente.

Para esto deben de cerrar todas las aplicaciones firefox y tambien todos los procesos firefox que se esten ejecutando, como el firefox-bin.
Ahora simplemente ejecutamos:
/opt/firefox/firefox-bin

Instalamos los plugins que deseamos y reiniciamos. Podemos cerrarlo despues por que es un poco pesado usar este ejecutable.

Para regresar a nuestro ejecutable de firefox, este es mas ligero porque pone de fondo a firefox-bin como un demonio:
/opt/firefox/firefox

Suerte.

martes, 21 de octubre de 2008

Testear la Memoria


Esta semana puse una Memoria RAM de 1MB, en el servidor de mi trabajo. pero causo que la máquina se colgará cada 6 horas, por momentos sentia que estaba usando Windows. Así que decidí hacer un test en la memoria RAM.

Una de las herramientas que nos puede salvar es MEMTEST. Podemos descargar el CD del sitio web, y instalarno de los paquetes de nuestra distribución, en mi caso Debian:
#aptitude install memtest86

Listo ahora esta instalado y debemos de modificar nuestro sistema de arranque GRUB, para que nos muestre como una opción el MemTest. Para esto modificamos el archivo /boot/grub/menu.lst
#emacs /boot/grub/menu.list

Recuerde que todo lo hacemos como super usuarios.

Ahora desmarcamos la linea que nos dice:
#mentest86=true
debe quedar así:
mentest86=true
Guardamos, y actualizamos grub:
#update-grub

Listo, al reiniciar nos mostrara la opción de MemTest para el testeo de memoria, ahora simplemente lo ejecutamos y listo, dejemos que de unas cuantas pasadas, para que nos muestre si la RAM esta dañada.

miércoles, 15 de octubre de 2008

Linux: Reparando el disco Duro

Estuve sufriendo, por los cortes de luz, que la computadora mandaba errores del disco duro, y algunas veces de PANIC KERNEL. Asi que decidi en comenzar a darle mantenimiento a la PC.

Primero veremos el tipo de partición que queremos reparar, ejecutando en consola:
#cat /etc/fstab
Esto nos listará las particiones del disco duro y su tipo de archivos, en mi PC aparece:

proc /proc proc defaults 0 0

/dev/hda1 / ext3 defaults,errors=remount-ro 0 1
/dev/hda6 /home ext3 defaults 0 2
/dev/hda5 none swap sw 0 0
/dev/hdc /media/cdrom0 udf,iso9660 user,noauto 0 0
/dev/fd0 /media/floppy0 auto rw,user,noauto 0 0

Pienso reparar la partición primaria que seria /dev/hda1 de tipo de archivos ext3. para eso utilizare la herramienta fsck.

Las reparaciones no se pueden realizar con el disco montado, así que es necesario hacerlo mediante un LiveCD. En mi caso encontre uno de Ubuntu 5.1, con el cual cargue el sistema, y en consola digite:
#fsck.ext3 -f -tt- v -D -y /dev/hda1
Si el tipo de partición fuese ext2:
#fsck.ext2 -f -tt- v -D -y /dev/hda1

Nota: En otras distribuciones se usa e2fsck en lugar de fsck.ext3 o fsck.ext2.


¿Qué significan tantas opciones?

Podemos ver en el man de fsck una pista de lo que estamos haciendo:
-f: Fuerza el chequeo del sistema de archivo, aunque paresca limpio.
-tt: Muestra las estadisticas de fsck.
-v: Modo de seguimiento, muestra los pasos desarrollados.
-D: Optimiza los directorios de la partición.
-y: Asume la respuesta YES en todas las preguntas.

Con esto terminamos el chequeo y reparación del disco. Ahora podemos reiniciar la PC para comenzar a trabajar.

miércoles, 28 de mayo de 2008

Video: Killer Tux

Tux, el poderoso guerrero enfrentandose a la máquina "casi" perfecta:



Un grandioso final.

miércoles, 21 de mayo de 2008

Descargar y convertir películas FLASH a VIDEO

Este es un pequeño tutorial que explica como descargar películas FLASH (de YouTube) y convertirlas en formato video (AVI).

Paso 1: Descargamos el video
Para descargar el video utilizaremos DownloadHelper, la cual es una extensión para Mozilla Firefox que permite descargar videos flash (flv) de distintas páginas. Aquí un video de su uso.








Instala la extensión haciendo click aquí

Paso 2: ffmpeg
ffmpeg es un visor, codificador y decodificador multimedia, con soporte para varios formatos. Para instalarlo utilizamos la siguiente orden:
#aptitude install ffmpeg

Paso 3: Conversión
Ahora procedemos a convertir el video que descargamos; el cual hemos llamado prueba.flv
#ffmpeg -i prueba.flv prueba.avi
Si quisieramos extraer solo el sonido usamos:
#ffmpeg -i prueba.flv -f mp3 prueba.mp3
Ahora veamos el video, para esto usaremos el reproductor de ffmpeg:
#ffplay prueba.avi

MEnconder: Otra alternativa
Otra alternativa distinta de ffmpeg es mencoder, este paquete no viene en debian asi que hay que añadir un nuevo repositorio:
# echo “deb http://www.debian-multimedia.org testing main” >> /etc/apt/sources.list
# apt-get update# apt-get install debian-multimedia-keyring
Ahora solo instalamos los paquetes necesarios
# aptitude install mencoder
Ahora convertimos nuestro archivo prueba.flv
#mencoder prueba.flv -ovc lavc -oac mp3lame -o prueba.avi

martes, 29 de abril de 2008

Instalación de Apache y TomCat

Esta semana se me dieron ganas de instalar Apache y Tomcat, en mi Debian Etch, y buscando en páginas amigas encontre este excelente tutorial desarrollado por Rodolfo Pilas (http://www.pilas.net), que tuve la oportunidad de conocer hace 2 años, y lo considero uno de los mas apasionados por el software Libre. Acá les dejo el enlace al tutorial:

http://pi.lastr.us/doku.php?id=documentos:apache_tomcat

jueves, 24 de abril de 2008

.:FLISOL 2008:. Puro Software Libre


El Festival Latinoamericano de Instalación de Software Libre (FLISoL) es el evento de difusión de Software Libre más grande en Latinoamérica. Se realiza desde el año 2005 y su principal objetivo es promover el uso del software libre, dando a conocer al público en general su filosofía, alcances, avances y desarrollo.
Para tal fin, las diversas comunidades locales de software libre (en cada país, en cada ciudad/localidad), organizan simultáneamente eventos en los que se instala, de manera gratuita y totalmente legal, software libre en las computadoras que llevan los asistentes. Además, en forma paralela, se ofrecen charlas, ponencias y talleres, sobre temáticas locales, nacionales y latinoamericanas en torno al Software Libre, en toda su gama de expresiones: artística, académica, empresarial y social.







En nuestra Tacna-Perú, el FLISOL se estará desarrollando el día sábado 26 a las 9:00 a.m. en el Local central de la Universidad Nacional Jorge Basadre Grohmann, sito en Av. Pinto con Av. Bolognesi s/n. Para mayores detalles visita la página:

http://flisol.info/
http://flisoltacna.info/

martes, 22 de abril de 2008

Mutt y envio de correo masivo

Muchas veces en instituciones es necesario enviar correos de manera masiva a los integrantes de la institución, por ejemplo enviar correos a los alumnos de un colegio. Para esto podemos utilizar nuestro querido mutt de la siguiente manera:

Paso1:
Creamos el contenido del correo en un archivo (contenido.txt)

Paso 2:
Creamos la lista de correos a los que vamos a enviar el contenido; esta la creeamos en el archivo listacorreo.txt

Paso 3:
Creamos un script bash (enviarcorreo.sh), con el siguiente contenido:

#!/bin/bash
mails=$(cat listacorreo.txt | sort | uniq)
contenido=$(cat contenido.txt)
for user in $mails
do
echo $contenido | mutt -s "Primer Envio" $user
echo "Enviando correo a $user"
done

Paso 4:
Ejecutamos:
#sh ./enviarcorreo.sh

¿Y si quiero que el contenido lo mande como HTML?
Simple, modifico el archivo de configuración de mutt (.mutt/muttrc) y añado la siguiente línea:
set content_type="text/html"

jueves, 10 de enero de 2008

Thunar y XArchiver


Thunar es un administrador de archivos para el escritorio XFCE; una de las características de Thunar es el grupo de plugins que posee; uno de estos es thunar-archive-plugin el cual permite crear y administrar archivos comprimidos de manera fácil y rápida; thunar-archive-plugin es un interfaz configurable para herramientas como ark (KDE) y file-roller(gnome). Pero buscando independencia de los demás escritorios en esta ocasión usaremos xarchiver como herramienta de compresión.

Paso 1: Instalación de XArchiver

Instalar xarchiver es muy sencillo:
#aptitude install xarchiver
si vemos su ayuda
#xarchiver --help

podemos destacar las siguientes opciones
-x, --extract-to=[destination path]
    Extrae el archivo en el directorio especificado y sale.
        xarchiver --extract-to=micarpeta miarchivo.tar.gz
-e, --extract=[archive path]
    Extrae el archivo preguntando el destino y sale.
        xarchiver --extract=micarpetapordefecto miarchivo.tar.gz
-d, --add-to=[file1] [file2] [file3] ... [fileN]
    Pregunta el nombre de archivo comprimido, añade los archivos y sale.
        xarchiver --add-to=miarchivo.tar.gz archivo1 archivo2 archivo3
-a, --add=[archive name]
    Añade los archivos seleccionados al archivo especifico y sale

Paso 2: ¿Cómo configurar thunar-archive-plugin para trabajar con xarchiver?

Al instalar xarchiver se creo el archivo /usr/share/applications/xarchiver.desktop esto indica que "podemos" configurar thunar-archive-plugin para que trabaje con nuestra aplicación. Para esto creamos el archivo /usr/lib/thunar-archive-plugin/thunar-archive-plugin/xarchiver.tap; el cual posee el script que se ejecutara cuando Thunar administre archivos comprimidos. El código de este archivo el siguiente:

#!/bin/sh
# Inicio de Código
# Sacamos de la pila de parámetros la acción y la carpeta
action=$1; shift;
folder=$1; shift;
# Analizamos la acción
case $action in
create)
exec xarchiver --add-to="archivo" "$@"
;;

extract-here)
exec xarchiver --extract-to="$folder" "$@"
;;

extract-to)
exec xarchiver --extract="$folder" "$@"
;;

*)
echo "Acción no soportada '$action'" >&2
exit 1
esac
# Fin de Código

Analizando el Código:
Existen 3 variables
action: Primer parámetro, indica la acción realizada create, extract-here, extract-to
folder: Segundo parámetro, indica el directorio donde se ejecuta la acción
@: Demás parámetros, archivos a los cuales se ejecuta la acción

Cuando la acción es create
exec xarchiver --add-to="archivo" "$@"
Muestra un un cuadro de dialogo presentando el nombre de archivo comprimido; en nuestro caso "archivo" será el nombre por defecto, al cual se añadiran los archivos $@

Cuando la acción es extract-here
exec xarchiver --extract-to="$folder" "$@"
Extrae el archivo comprimido $@ en la carpeta actual ($folder)

Cuando la acción es extract-to
exec xarchiver --extract="$folder" "$@"
Muestra un cuadro de dialogo preguntando la carpeta donde se extraerá el archivo comprimido ($@). Por defecto aparecerá $folder como carpeta.

Paso 3: Puliendo la aplicación
Antes de probar xarchiver con debemos de verificar que no se tengan instalados file-roller o ark. o eliminar los archivos
/usr/lib/thunar-archive-plugin/thunar-archive-plugin/ark.tap
/usr/lib/thunar-archive-plugin/thunar-archive-plugin/file-roller.tap

Listo, tenemos Thunar trabajando con XArchiver. Ahora cada vez que hagan clic derecho sobre un archivo tendrán las opciones de compresión habilitadas con XArchiver.

Salvapantallas (xscreensaver) en XFCE


XFCE es un escritorio muy potente, pero una de sus desventajas es no poseer un Salva-pantallas por defecto (en la instalación), así que tendremos que instalar el Salva-pantallas a mano. Para esto usaremos XScreensaver, como administrador de Salva-pantallas.

Paso 1: Instalación
#aptitude install xscreensaver

Paso 2: Arrancar el demonio
Ahora solo debemos de crear o modificar nuestro archivo $HOME/.xsession, el cual se ejecuta cuando el usuario inicia sesión. A este archivo añadimos estas líneas:

xscreensaver -nosplash &
exec xfce4-session

la primera línea ejecuta xscreensaver como demonio y la segunda línea ejecuta nuestro escritorio XFCE4.

Paso 3: Configuración
Podemos cambiar de Salva-pantallas utilizando el comando
#xscreensaver-command -prefs

o también aparecerá por defecto en nuestro menú de configuración de XFCE.

Listo, tenemos nuestro Salva-pantallas funcionando.

Emacs en windows: arranque rápido

En windows la carga de emacs implica una demora en windows pero se puede mejorar usando el demonio de emacs y modificar la llamada usando el...